==> apache-kylin-5.0.0-source-release.zip: apache-kylin-5.0.0/src/data-loading-server/src/main/java/org/apache/kylin/rest/controller/JobResourceController.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kylin.rest.controller;

import static org.apache.kylin.common.constant.HttpConstant.HTTP_VND_APACHE_KYLIN_JSON;
import static org.apache.kylin.common.constant.HttpConstant.HTTP_VND_APACHE_KYLIN_V4_PUBLIC_JSON;

import java.io.IOException;
import java.util.Set;

import org.apache.kylin.job.service.JobResourceService;
import org.apache.kylin.job.service.JobResourceService.JobResource;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping(value = "/api/resource/job", produces = { HTTP_VND_APACHE_KYLIN_JSON,
        HTTP_VND_APACHE_KYLIN_V4_PUBLIC_JSON })
public class JobResourceController {

    @Autowired
    private JobResourceService jobResourceService;

    @PutMapping(value = "/adjust")
    @ResponseBody
    public JobResource adjustJobResource(@RequestBody JobResource resource) throws IOException {
        return jobResourceService.adjustJobResource(resource);
    }

    @GetMapping(value = "/queueNames")
    @ResponseBody
    public Set<String> getQueueNames() {
        return jobResourceService.getQueueNames();
    }

}

==> apache-kylin-5.0.2-source-release.zip: apache-kylin-5.0.2/src/data-loading-server/src/main/java/org/apache/kylin/rest/controller/JobResourceController.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kylin.rest.controller;

import static org.apache.kylin.common.constant.HttpConstant.HTTP_VND_APACHE_KYLIN_JSON;
import static org.apache.kylin.common.constant.HttpConstant.HTTP_VND_APACHE_KYLIN_V4_PUBLIC_JSON;

import java.io.IOException;
import java.util.Set;

import org.apache.kylin.rest.service.JobResourceService;
import org.apache.kylin.rest.service.JobResourceService.JobResource;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping(value = "/api/resource/job", produces = { HTTP_VND_APACHE_KYLIN_JSON,
        HTTP_VND_APACHE_KYLIN_V4_PUBLIC_JSON })
public class JobResourceController {

    @Autowired
    private JobResourceService jobResourceService;

    @PutMapping(value = "/adjust")
    @ResponseBody
    public JobResource adjustJobResource(@RequestBody JobResource resource) throws IOException {
        return jobResourceService.adjustJobResource(resource);
    }

    @GetMapping(value = "/queueNames")
    @ResponseBody
    public Set<String> getQueueNames() {
        return jobResourceService.getQueueNames();
    }

}
